@@ -1,8 +1,10 @@
 package ETL::Yertl::Command::ygrok;
+our $VERSION = '0.028';
 # ABSTRACT: Parse lines of text into documents
-$ETL::Yertl::Command::ygrok::VERSION = '0.027';
+
 use ETL::Yertl;
 use Getopt::Long qw( GetOptionsFromArray );
+use ETL::Yertl::Format::default;
 use ETL::Yertl::Format::yaml;
 use Regexp::Common;
 use File::HomeDir;
@@ -150,13 +152,13 @@ sub main {
                     say $pattern;
                 }
                 else {
-                    my $out_fmt = ETL::Yertl::Format::yaml->new;
+                    my $out_fmt = ETL::Yertl::Format::default->new;
                     say $out_fmt->write( $pattern );
                 }
             }
             else {
                 # Show all patterns we know about
-                my $out_fmt = ETL::Yertl::Format::yaml->new;
+                my $out_fmt = ETL::Yertl::Format::default->new;
                 say $out_fmt->write( $patterns );
             }
         }
@@ -173,7 +175,7 @@ sub main {
         $re = qr{^$re$};
     }
 
-    my $out_formatter = ETL::Yertl::Format::yaml->new;
+    my $out_formatter = ETL::Yertl::Format::default->new;
     push @files, "-" unless @files;
     for my $file ( @files ) {
 
@@ -286,7 +288,7 @@ ETL::Yertl::Command::ygrok - Parse lines of text into documents
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 AUTHOR
 
@@ -294,7 +296,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Doug Bell.
+This software is copyright (c) 2016 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
