@@ -1,8 +1,9 @@
 package ETL::Yertl::Command::ymask;
+our $VERSION = '0.028';
 # ABSTRACT: Filter documents through applying a mask
-$ETL::Yertl::Command::ymask::VERSION = '0.027';
+
 use ETL::Yertl;
-use ETL::Yertl::Format::yaml;
+use ETL::Yertl::Format::default;
 use Data::Partial::Google;
 
 sub main {
@@ -18,7 +19,7 @@ sub main {
     die "Must give a mask\n" unless $mask;
 
     my $filter = Data::Partial::Google->new( $mask );
-    my $out_fmt = ETL::Yertl::Format::yaml->new;
+    my $out_fmt = ETL::Yertl::Format::default->new;
 
     push @files, "-" unless @files;
     for my $file ( @files ) {
@@ -35,7 +36,7 @@ sub main {
             }
         }
 
-        my $in_fmt = ETL::Yertl::Format::yaml->new( input => $fh );
+        my $in_fmt = ETL::Yertl::Format::default->new( input => $fh );
         for my $doc ( $in_fmt->read ) {
             print $out_fmt->write( $filter->mask( $doc ) );
         }
@@ -54,7 +55,7 @@ ETL::Yertl::Command::ymask - Filter documents through applying a mask
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 AUTHOR
 
@@ -62,7 +63,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Doug Bell.
+This software is copyright (c) 2016 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
