@@ -1,6 +1,7 @@
 package ETL::Yertl::Command::yq::RecDescentTree;
+our $VERSION = '0.028';
 # ABSTRACT: A Parse::RecDescent-based parser using a parse tree
-$ETL::Yertl::Command::yq::RecDescentTree::VERSION = '0.027';
+
 use ETL::Yertl;
 use boolean qw( :all );
 use Parse::RecDescent;
@@ -18,6 +19,7 @@ sub is_list { return ref $_[0] eq 'list' }
 sub flatten { map { is_list( $_ ) ? @$_ : $_ } @_ }
 sub list { return bless [ flatten( @_ ) ], 'list' }
 sub empty { return bless {}, 'empty' }
+sub is_empty { return ref $_[0] eq 'empty' }
 
 my $grammar = q{
     <autotree>
@@ -162,10 +164,17 @@ sub run_expr {
 
 sub run_filter {
     my ( $filter, $document, $scope ) = @_;
+
+    # Empty things cannot contain anything to filter
+    if ( is_empty( $document ) ) {
+        return $document;
+    }
+
     yertl::diag( 1, "Filter: " . Dumper $filter );
     if ( !$filter->{'filter_part(s?)'} ) {
         return $document;
     }
+
     for my $part ( @{ $filter->{'filter_part(s?)'} } ) {
         if ( $part->{word} ) {
             $document = $document->{ $part->{word}{__VALUE__} };
@@ -254,7 +263,7 @@ ETL::Yertl::Command::yq::RecDescentTree - A Parse::RecDescent-based parser using
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 AUTHOR
 
@@ -262,7 +271,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Doug Bell.
+This software is copyright (c) 2016 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
