@@ -1,9 +1,11 @@
 package ETL::Yertl::Command::ysql;
+our $VERSION = '0.028';
 # ABSTRACT: Read and write documents with a SQL database
-$ETL::Yertl::Command::ysql::VERSION = '0.027';
+
 use ETL::Yertl;
 use Getopt::Long qw( GetOptionsFromArray :config pass_through );
 use ETL::Yertl::Format::yaml;
+use ETL::Yertl::Format::default;
 use File::HomeDir;
 use Path::Tiny qw( tempfile );
 use SQL::Abstract;
@@ -43,7 +45,7 @@ sub main {
     #; say Dumper \@args;
     #; say Dumper \%opt;
 
-    my $out_fmt = ETL::Yertl::Format::yaml->new;
+    my $out_fmt = ETL::Yertl::Format::default->new;
 
     if ( $opt{config} ) {
         my $db_key = shift @args;
@@ -165,7 +167,7 @@ sub main {
         # with every document inserted.
         if ( $opt{insert} ) {
             if ( !-t *STDIN ) {
-                my $in_fmt = ETL::Yertl::Format::yaml->new( input => \*STDIN );
+                my $in_fmt = ETL::Yertl::Format::default->new( input => \*STDIN );
 
                 my $query;
                 my @bind_args;
@@ -227,7 +229,7 @@ sub main {
             or die "SQL error in prepare: " . $dbh->errstr . "\n";
 
         if ( !-t *STDIN ) {
-            my $in_fmt = ETL::Yertl::Format::yaml->new( input => \*STDIN );
+            my $in_fmt = ETL::Yertl::Format::default->new( input => \*STDIN );
 
             for my $doc ( $in_fmt->read ) {
                 $sth->execute( map { select_doc( $_, $doc ) } @fields )
@@ -321,7 +323,7 @@ ETL::Yertl::Command::ysql - Read and write documents with a SQL database
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 AUTHOR
 
@@ -329,7 +331,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Doug Bell.
+This software is copyright (c) 2016 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
