@@ -1,9 +1,10 @@
 package ETL::Yertl::Command::yto;
+our $VERSION = '0.028';
 # ABSTRACT: Write documents to a format like JSON or CSV
-$ETL::Yertl::Command::yto::VERSION = '0.027';
+
 use ETL::Yertl;
 use Module::Runtime qw( use_module compose_module_name is_module_spec );
-use ETL::Yertl::Format::yaml;
+use ETL::Yertl::Format::default;
 
 sub main {
     my $class = shift;
@@ -48,7 +49,7 @@ sub main {
             }
         }
 
-        my $in_fmt = ETL::Yertl::Format::yaml->new( input => $fh );
+        my $in_fmt = ETL::Yertl::Format::default->new( input => $fh );
         print $out_fmt->write( $in_fmt->read );
     }
 }
@@ -65,7 +66,7 @@ ETL::Yertl::Command::yto - Write documents to a format like JSON or CSV
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 SYNOPSIS
 
@@ -89,7 +90,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Doug Bell.
+This software is copyright (c) 2016 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
