@@ -1,16 +1,47 @@
 package ETL::Yertl::Format::csv;
+our $VERSION = '0.028';
 # ABSTRACT: CSV read/write support for Yertl
-$ETL::Yertl::Format::csv::VERSION = '0.027';
+
 use ETL::Yertl 'Class';
 use Module::Runtime qw( use_module );
 use List::Util qw( pairs pairkeys pairfirst );
 
+#pod =attr input
+#pod
+#pod The filehandle to read from for input.
+#pod
+#pod =cut
 
 has input => (
     is => 'ro',
     isa => FileHandle,
 );
 
+#pod =attr delimiter
+#pod
+#pod The delimited to use. Defaults to C<,>. Other common values include C<:>.
+#pod
+#pod =cut
+
+has delimiter => (
+    is => 'ro',
+    isa => Str,
+    default => ',',
+);
+
+#pod =attr format_module
+#pod
+#pod The module being used for this format. Possible modules, in order of importance:
+#pod
+#pod =over 4
+#pod
+#pod =item L<Text::CSV_XS> (any version)
+#pod
+#pod =item L<Text::CSV> (any version)
+#pod
+#pod =back
+#pod
+#pod =cut
 
 # Pairs of module => supported version
 our @FORMAT_MODULES = (
@@ -22,13 +53,13 @@ has format_module => (
     is => 'rw',
     isa => sub {
         my ( $format_module ) = @_;
-        die "format_module must be one of: " . join " ", pairkeys @FORMAT_MODULES
+        die "format_module must be one of: " . join( " ", pairkeys @FORMAT_MODULES ) . "\n"
             unless pairfirst { $a eq $format_module } @FORMAT_MODULES;
         eval {
             use_module( $format_module );
         };
         if ( $@ ) {
-            die "Could not load format module '$format_module'";
+            die "Could not load format module '$format_module': $@";
         }
     },
     lazy => 1,
@@ -43,9 +74,11 @@ has format_module => (
             }
         }
         die "Could not load a formatter for CSV. Please install one of the following modules:\n"
-            . join "",
+            . join( "",
                 map { sprintf "\t%s (%s)", $_->[0], $_->[1] ? "version $_->[1]" : "Any version" }
-                pairs @FORMAT_MODULES;
+                pairs @FORMAT_MODULES
+            )
+            . "\n";
     },
 );
 
@@ -60,10 +93,18 @@ has _csv => (
     lazy => 1,
     default => sub {
         my ( $self ) = @_;
-        $self->format_module->new({ binary => 1, eol => $\ });
+        $self->format_module->new({
+            binary => 1, eol => $\,
+            sep_char => $self->delimiter,
+        });
     },
 );
 
+#pod =method write( DOCUMENTS )
+#pod
+#pod Convert the given C<DOCUMENTS> to CSV. Returns a CSV string.
+#pod
+#pod =cut
 
 sub write {
     my ( $self, @docs ) = @_;
@@ -86,6 +127,11 @@ sub write {
     return $str;
 }
 
+#pod =method read()
+#pod
+#pod Read a CSV string from L<input> and return all the documents.
+#pod
+#pod =cut
 
 sub read {
     my ( $self ) = @_;
@@ -118,7 +164,7 @@ ETL::Yertl::Format::csv - CSV read/write support for Yertl
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 ATTRIBUTES
 
@@ -126,6 +172,10 @@ version 0.027
 
 The filehandle to read from for input.
 
+=head2 delimiter
+
+The delimited to use. Defaults to C<,>. Other common values include C<:>.
+
 =head2 format_module
 
 The module being used for this format. Possible modules, in order of importance:
@@ -154,7 +204,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Doug Bell.
+This software is copyright (c) 2016 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
