@@ -1,16 +1,35 @@
 package ETL::Yertl::Format::json;
+our $VERSION = '0.028';
 # ABSTRACT: JSON read/write support for Yertl
-$ETL::Yertl::Format::json::VERSION = '0.027';
+
 use ETL::Yertl 'Class';
 use Module::Runtime qw( use_module );
 use List::Util qw( pairs pairkeys pairfirst );
 
+#pod =attr input
+#pod
+#pod The filehandle to read from for input.
+#pod
+#pod =cut
 
 has input => (
     is => 'ro',
     isa => FileHandle,
 );
 
+#pod =attr format_module
+#pod
+#pod The module being used for this format. Possible modules, in order of importance:
+#pod
+#pod =over 4
+#pod
+#pod =item L<JSON::XS> (any version)
+#pod
+#pod =item L<JSON::PP> (any version)
+#pod
+#pod =back
+#pod
+#pod =cut
 
 # Pairs of module => supported version
 our @FORMAT_MODULES = (
@@ -22,13 +41,13 @@ has format_module => (
     is => 'rw',
     isa => sub {
         my ( $format_module ) = @_;
-        die "format_module must be one of: " . join " ", pairkeys @FORMAT_MODULES
+        die "format_module must be one of: " . join( " ", pairkeys @FORMAT_MODULES ) . "\n"
             unless pairfirst { $a eq $format_module } @FORMAT_MODULES;
         eval {
             use_module( $format_module );
         };
         if ( $@ ) {
-            die "Could not load format module '$format_module'";
+            die "Could not load format module '$format_module': $@";
         }
     },
     lazy => 1,
@@ -43,9 +62,11 @@ has format_module => (
             }
         }
         die "Could not load a formatter for JSON. Please install one of the following modules:\n"
-            . join "",
+            . join( "",
                 map { sprintf "\t%s (%s)", $_->[0], $_->[1] ? "version $_->[1]" : "Any version" }
-                pairs @FORMAT_MODULES;
+                pairs @FORMAT_MODULES
+            )
+            . "\n";
     },
 );
 
@@ -97,12 +118,22 @@ my %FORMAT_SUB = (
 
 );
 
+#pod =method write( DOCUMENTS )
+#pod
+#pod Convert the given C<DOCUMENTS> to JSON. Returns a JSON string.
+#pod
+#pod =cut
 
 sub write {
     my $self = shift;
     return $FORMAT_SUB{ $self->format_module }{write}->( $self, @_ );
 }
 
+#pod =method read()
+#pod
+#pod Read a JSON string from L<input> and return all the documents
+#pod
+#pod =cut
 
 sub read {
     my $self = shift;
@@ -121,7 +152,7 @@ ETL::Yertl::Format::json - JSON read/write support for Yertl
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 SYNOPSIS
 
@@ -159,7 +190,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Doug Bell.
+This software is copyright (c) 2016 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
