@@ -1,35 +1,59 @@
 package ETL::Yertl::Format::yaml;
+our $VERSION = '0.028';
 # ABSTRACT: YAML read/write support for Yertl
-$ETL::Yertl::Format::yaml::VERSION = '0.027';
+
 use ETL::Yertl 'Class';
 use Module::Runtime qw( use_module );
 use List::Util qw( pairs pairkeys pairfirst );
 
+#pod =attr input
+#pod
+#pod The filehandle to read from for input.
+#pod
+#pod =cut
 
 has input => (
     is => 'ro',
     isa => FileHandle,
 );
 
+#pod =attr format_module
+#pod
+#pod The module being used for this format. Possible modules, in order of importance:
+#pod
+#pod =over 4
+#pod
+#pod =item L<YAML::XS> (any version)
+#pod
+#pod =item L<YAML::Syck> (any version)
+#pod
+#pod =item L<YAML> (any version)
+#pod
+#pod =item L<YAML::Tiny> (any version)
+#pod
+#pod =back
+#pod
+#pod =cut
 
 # Pairs of module => supported version
 our @FORMAT_MODULES = (
     'YAML::XS' => 0,
     'YAML::Syck' => 0,
     'YAML' => 0,
+    'YAML::Tiny' => 0,
 );
 
 has format_module => (
     is => 'rw',
     isa => sub {
         my ( $format_module ) = @_;
-        die "format_module must be one of: " . join " ", pairkeys @FORMAT_MODULES
+        die "format_module must be one of: " . join( " ", pairkeys @FORMAT_MODULES ) . "\n"
             unless pairfirst { $a eq $format_module } @FORMAT_MODULES;
         eval {
             use_module( $format_module );
         };
         if ( $@ ) {
-            die "Could not load format module '$format_module'";
+            die "Could not load format module '$format_module': $@";
         }
     },
     lazy => 1,
@@ -44,9 +68,11 @@ has format_module => (
             }
         }
         die "Could not load a formatter for YAML. Please install one of the following modules:\n"
-            . join "",
+            . join( "",
                 map { sprintf "\t%s (%s)", $_->[0], $_->[1] ? "version $_->[1]" : "Any version" }
-                pairs @FORMAT_MODULES;
+                pairs @FORMAT_MODULES
+            )
+            . "\n";
     },
 );
 
@@ -95,14 +121,39 @@ my %FORMAT_SUB = (
         },
 
     },
+
+    'YAML::Tiny' => {
+        write => sub {
+            my $self = shift;
+            return YAML::Tiny::Dump( @_ );
+        },
+
+        read => sub {
+            my $self = shift;
+            my $yaml = do { local $/; readline $self->input };
+            return $yaml ? YAML::Tiny::Load( $yaml ) : ();
+        },
+
+    },
+
 );
 
+#pod =method write( DOCUMENTS )
+#pod
+#pod Convert the given C<DOCUMENTS> to YAML. Returns a YAML string.
+#pod
+#pod =cut
 
 sub write {
     my $self = shift;
     return $FORMAT_SUB{ $self->format_module }{write}->( $self, @_ );
 }
 
+#pod =method read()
+#pod
+#pod Read a YAML string from L<input> and return all the documents.
+#pod
+#pod =cut
 
 sub read {
     my $self = shift;
@@ -121,7 +172,7 @@ ETL::Yertl::Format::yaml - YAML read/write support for Yertl
 
 =head1 VERSION
 
-version 0.027
+version 0.028
 
 =head1 ATTRIBUTES
 
@@ -141,6 +192,8 @@ The module being used for this format. Possible modules, in order of importance:
 
 =item L<YAML> (any version)
 
+=item L<YAML::Tiny> (any version)
+
 =back
 
 =head1 METHODS
@@ -159,7 +212,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Doug Bell.
+This software is copyright (c) 2016 by Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
